Module array

Module array 

Implements the tensor struct and associated methods for the Openqudit library.

Structs

SymSqTensor
A tensor with D dimensions, where the first two dimensions are equal and symmetric.
SymSqTensorMut
A mutable reference to a symmetric square tensor.
SymSqTensorRef
An immutable reference to a symmetric square tensor.
Tensor
A tensor struct that holds data in an aligned memory buffer.
TensorMut
A mutable view into tensor data.
TensorRef
An immutable view into tensor data.