SymSqTensor

Struct SymSqTensor 

pub struct SymSqTensor<C: Memorable, const D: usize> { /* private fields */ }
A tensor with D dimensions, where the first two dimensions are equal and symmetric.

Implementations

Source

impl<C: Memorable, const D: usize> SymSqTensor<C, D>

pub fn new(data: MemoryBuffer<C>, dims: [usize; D], strides: [usize; D]) -> Self

Creates a new symmetric square tensor with the given data, dimensions, and strides.

pub fn zeros(dims: [usize; D]) -> Self

Creates a new symmetric square tensor filled with zeros.

pub fn dims(&self) -> &[usize; D]

Returns a reference to the dimensions of the tensor.

pub fn strides(&self) -> &[usize; D]

Returns a reference to the strides of the tensor.

pub fn rank(&self) -> usize

Returns the rank (number of dimensions) of the tensor.

pub fn num_elements(&self) -> usize

Returns the total number of elements in the tensor.

pub fn as_ptr(&self) -> *const C

Returns a raw pointer to the tensor’s data.

pub fn as_ptr_mut(&mut self) -> *mut C

Returns a mutable raw pointer to the tensor’s data.

pub fn as_ref(&self) -> SymSqTensorRef<'_, C, D>

Returns an immutable reference to the tensor.

pub fn as_mut(&mut self) -> SymSqTensorMut<'_, C, D>

Returns a mutable reference to the tensor.

pub fn get(&self, indices: &[usize; D]) -> &C

Returns a reference to an element at the given indices.

Panics

Panics if the indices are out of bounds.

pub fn get_mut(&mut self, indices: &[usize; D]) -> &mut C

Returns a mutable reference to an element at the given indices.

Panics

Panics if the indices are out of bounds.

pub unsafe fn get_unchecked(&self, indices: &[usize; D]) -> &C

Returns an immutable reference to an element at the given indices, without performing bounds checks.

Safety

Calling this method with out-of-bounds indices is undefined behavior.

pub unsafe fn get_mut_unchecked(&mut self, indices: &[usize; D]) -> &mut C

Returns a mutable reference to an element at the given indices, without performing bounds checks.

Safety

Calling this method with out-of-bounds indices is undefined behavior.

pub unsafe fn ptr_at(&self, indices: &[usize; D]) -> *const C

Returns a raw pointer to an element at the given indices, without performing bounds checks.

Safety

Calling this method with out-of-bounds indices is undefined behavior.

pub unsafe fn ptr_at_mut(&mut self, indices: &[usize; D]) -> *mut C

Returns a mutable raw pointer to an element at the given indices, without performing bounds checks.

Safety

Calling this method with out-of-bounds indices is undefined behavior.

Source

impl<C: Memorable> SymSqTensor<C, 5>

pub fn subtensor_ref(&self, m1: usize, m2: usize) -> TensorRef<'_, C, 3>

Returns an immutable reference to the 3D subtensor at the given matrix indices.

pub fn subtensor_mut(&mut self, m1: usize, m2: usize) -> TensorMut<'_, C, 3>

Returns a mutable reference to the 3D subtensor at the given matrix indices.

pub unsafe fn subtensor_ref_unchecked( &self, m1: usize, m2: usize, ) -> TensorRef<'_, C, 3>

Returns an immutable reference to the 3D subtensor at the given matrix indices without bounds checking.

Safety

Caller should ensure that m1 and m2 are in bounds.

pub unsafe fn subtensor_mut_unchecked( &mut self, m1: usize, m2: usize, ) -> TensorMut<'_, C, 3>

Returns a mutable reference to the 3D subtensor at the given matrix indices without bounds checking.

Safety

Caller should ensure that m1 and m2 are in bounds.

Source

impl<C: Memorable> SymSqTensor<C, 4>

pub fn subtensor_ref(&self, m1: usize, m2: usize) -> MatRef<'_, C>

Returns an immutable matrix reference to the subtensor at the given indices.

pub fn subtensor_mut(&mut self, m1: usize, m2: usize) -> MatMut<'_, C>

Returns a mutable matrix reference to the subtensor at the given indices.

pub unsafe fn subtensor_ref_unchecked( &self, m1: usize, m2: usize, ) -> MatRef<'_, C>

Returns an immutable matrix reference to the subtensor at the given indices without bounds checking.

Safety

Caller should ensure that m1 and m2 are in bounds.

pub unsafe fn subtensor_mut_unchecked( &mut self, m1: usize, m2: usize, ) -> MatMut<'_, C>

Returns a mutable matrix reference to the subtensor at the given indices without bounds checking.

Safety

Caller should ensure that m1 and m2 are in bounds.

Source

impl<C: Memorable> SymSqTensor<C, 3>

pub fn subtensor_ref(&self, m1: usize, m2: usize) -> RowRef<'_, C>

Returns an immutable row reference to the subtensor at the given indices.

pub fn subtensor_mut(&mut self, m1: usize, m2: usize) -> RowMut<'_, C>

Returns a mutable row reference to the subtensor at the given indices.

pub unsafe fn subtensor_ref_unchecked( &self, m1: usize, m2: usize, ) -> RowRef<'_, C>

Returns an immutable row reference to the subtensor at the given indices without bounds checking.

Safety

Caller should ensure that m1 and m2 are in bounds.

pub unsafe fn subtensor_mut_unchecked( &mut self, m1: usize, m2: usize, ) -> RowMut<'_, C>

Returns a mutable row reference to the subtensor at the given indices without bounds checking.

Safety

Caller should ensure that m1 and m2 are in bounds.

Source

impl<C: Memorable> SymSqTensor<C, 2>

pub fn subtensor_ref(&self, m1: usize, m2: usize) -> &C

Returns an immutable reference to the element at the given indices.

pub fn subtensor_mut(&mut self, m1: usize, m2: usize) -> &mut C

Returns a mutable reference to the element at the given indices.

pub unsafe fn subtensor_ref_unchecked(&self, m1: usize, m2: usize) -> &C

Returns an immutable reference to the element at the given indices without bounds checking.

Safety

Caller should ensure that m1 and m2 are in bounds.

pub unsafe fn subtensor_mut_unchecked(&mut self, m1: usize, m2: usize) -> &mut C

Returns a mutable reference to the element at the given indices without bounds checking.

Safety

Caller should ensure that m1 and m2 are in bounds.