SymSqTensorRef

Struct SymSqTensorRef 

pub struct SymSqTensorRef<'a, C: Memorable, const D: usize> { /* private fields */ }
An immutable reference to a symmetric square tensor.

Implementations

Source

impl<'a, C: Memorable, const D: usize> SymSqTensorRef<'a, C, D>

pub unsafe fn from_raw_parts( data: *const C, dims: [usize; D], strides: [usize; D], ) -> Self

Creates a new SymSqTensorRef from raw parts.

Safety

The caller must ensure that data points to a valid memory block of C elements, and that dims and strides accurately describe the layout of the tensor within that memory block. The data pointer must be valid for the lifetime 'a.

pub fn dims(&self) -> &[usize; D]

Returns a reference to the dimensions of the tensor.

pub fn strides(&self) -> &[usize; D]

Returns a reference to the strides of the tensor.

pub fn rank(&self) -> usize

Returns the rank (number of dimensions) of the tensor.

pub fn num_elements(&self) -> usize

Returns the total number of elements in the tensor.

pub fn as_ptr(&self) -> *const C

Returns a raw pointer to the tensor’s data.

pub fn get(&self, indices: &[usize; D]) -> &C

Returns a reference to an element at the given indices.

Panics

Panics if the indices are out of bounds.

pub unsafe fn get_unchecked(&self, indices: &[usize; D]) -> &C

Returns an immutable reference to an element at the given indices, without performing bounds checks.

Safety

Calling this method with out-of-bounds indices is undefined behavior.

pub unsafe fn ptr_at(&self, indices: &[usize; D]) -> *const C

Returns a raw pointer to an element at the given indices, without performing bounds checks.

Safety

Calling this method with out-of-bounds indices is undefined behavior.

Source

impl<'a, C: Memorable> SymSqTensorRef<'a, C, 5>

pub fn subtensor_ref(&self, m1: usize, m2: usize) -> TensorRef<'a, C, 3>

Returns an immutable reference to the 3D subtensor at the given matrix indices.

pub unsafe fn subtensor_ref_unchecked( &self, m1: usize, m2: usize, ) -> TensorRef<'a, C, 3>

Returns an immutable reference to the 3D subtensor at the given matrix indices without bounds checking.

Safety

Caller should ensure that m1 and m2 are in bounds.

Source

impl<'a, C: Memorable> SymSqTensorRef<'a, C, 4>

pub fn subtensor_ref(&self, m1: usize, m2: usize) -> MatRef<'a, C>

Returns an immutable matrix reference to the subtensor at the given indices.

pub unsafe fn subtensor_ref_unchecked( &self, m1: usize, m2: usize, ) -> MatRef<'a, C>

Returns an immutable matrix reference to the subtensor at the given indices without bounds checking.

Safety

Caller should ensure that m1 and m2 are in bounds.

Source

impl<'a, C: Memorable> SymSqTensorRef<'a, C, 3>

pub fn subtensor_ref(&self, m1: usize, m2: usize) -> RowRef<'a, C>

Returns an immutable row reference to the subtensor at the given indices.

pub unsafe fn subtensor_ref_unchecked( &self, m1: usize, m2: usize, ) -> RowRef<'a, C>

Returns an immutable row reference to the subtensor at the given indices without bounds checking.

Safety

Caller should ensure that m1 and m2 are in bounds.

Source

impl<'a, C: Memorable> SymSqTensorRef<'a, C, 2>

pub fn subtensor_ref(&self, m1: usize, m2: usize) -> &C

Returns an immutable reference to the element at the given indices.

pub unsafe fn subtensor_ref_unchecked(&self, m1: usize, m2: usize) -> &C

Returns an immutable reference to the element at the given indices without bounds checking.

Safety

Caller should ensure that m1 and m2 are in bounds.