HybridSystem

Trait HybridSystem 

pub trait HybridSystem: QuditSystem + ClassicalSystem {
    // Provided methods
    fn qudit_radices(&self) -> Radices { ... }
    fn dit_radices(&self) -> Radices { ... }
    fn is_pure_quantum(&self) -> bool { ... }
    fn is_classical_only(&self) -> bool { ... }
    fn is_hybrid(&self) -> bool { ... }
}
A data structure that consists of or operates on a hybrid quantum-classical system.

Provided Methods

fn qudit_radices(&self) -> Radices

Returns the radices of the qudits in the system.

Returns

A [QuditRadices] instance representing the radices of the qudits.

fn dit_radices(&self) -> Radices

Returns the radices of the dits in the system.

Returns

A [QuditRadices] instance representing the radices of the dits.

fn is_pure_quantum(&self) -> bool

Checks if the system is purely quantum with no classical bits.

Returns

true if there are no classical bits, otherwise false.

fn is_classical_only(&self) -> bool

Checks if the system is purely classical with no qudits.

Returns

true if there are no qudits, otherwise false.

fn is_hybrid(&self) -> bool

Checks if the system is hybrid with both qudits and classical bits.

Returns

true if there are both qudits and classical bits, otherwise false.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors