pub unsafe fn kron_kernel_raw<C: Mul<Output = C> + Copy>(
dst: *mut C,
dst_rs: isize,
dst_cs: isize,
lhs: *const C,
lhs_nrows: usize,
lhs_ncols: usize,
lhs_rs: isize,
lhs_cs: isize,
rhs: *const C,
rhs_nrows: usize,
rhs_ncols: usize,
rhs_rs: isize,
rhs_cs: isize,
)Expand description
Perform a kroneckor product between two matrix buffers.
Safety
Caller must ensure that pointers point to properly addressable memory that describe matrices with dimensions and strides given.