Implements the tensor struct and associated methods for the Openqudit library.
Structs
- SymSq
Tensor - A tensor with D dimensions, where the first two dimensions are equal and symmetric.
- SymSq
Tensor Mut - A mutable reference to a symmetric square tensor.
- SymSq
Tensor Ref - An immutable reference to a symmetric square tensor.
- Tensor
- A tensor struct that holds data in an aligned memory buffer.
- Tensor
Mut - A mutable view into tensor data.
- Tensor
Ref - An immutable view into tensor data.