Memory management types and helper functions for the Openqudit library.
Traits
- Memorable
- A trait for types that can be stored in memory buffers.
Functions
- alloc_
zeroed_ memory - Allocate a new memory buffer with the given size.
- calc_
col_ stride - Calculate column stride for a matrix with given rows and columns.
- calc_
mat_ stride - Calculate matrix stride for a tensor with given rows, columns, and column stride.
- calc_
next_ stride - Calculates a subtensor’s stride, given its size. We ensure the subtensor is aligned to cachelines.
Type Aliases
- Memory
Buffer - An aligned memory buffer.
- Memory
Pointer - A pointer to an element in a memory buffer.
- Memory
Pointer Mut - A mutable pointer to an element in a memory buffer.
- Memory
Pointer NonNull - A const non-null pointer to an element in a memory buffer.